==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/sr-CS/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Ovaj korisnik može da se uloguje',
    'activated_disabled_help_text' => 'Ne možete da menjate status aktivacije za sopstveni nalog.',
    'assets_user'       => 'Imovina dodijeljena za :name',
    'bulk_update_warn'	=> 'Nameravate uređivati ​​svojstva korisnika :user_count users. Imajte na umu da ne možete menjati vlastite korisničke atribute pomoću ovog obrasca i morati sami uređivati ​​vlastiti nalog pojedinačno.',
    'bulk_update_help'	=> 'Ovaj vam obrazac omogućava ažuriranje više korisnika odjednom. Popunite polja koja su vam potrebna za promjenu. Sva polja koja su ostala prazna će ostati nepromenjena.',
    'current_assets'    => 'Imovina dodeljena ovom koriniku',
    'clone'             => 'Kloniraj korisnika',
    'contact_user'      => 'Kontakt :name',
    'edit'              => 'Edit User',
    'filetype_info'     => 'Dopuštene vrste datoteka su png, gif, jpg, jpeg, doc, docx, pdf, txt, zip i rar.',
    'history_user'      => 'Istorija za :name',
	'info'				=> 'Info',
    'restore_user'		=> 'Kliknite ovdje da biste ih vratili.',
    'last_login'        => 'Poslednja prijava',
    'ldap_config_text'  => 'Postavke LDAP konfiguracije mogu se pronaći u Administrator> Postavke. Odabrana lokacija (opcionalno) će biti podešena za sve importovane korisnike.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Software Checked out to :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Prikaži korisnika :name',
    'usercsv'           => 'CSV file',
    'two_factor_admin_optin_help' => 'Your current admin settings allow selective enforcement of two-factor authentication.  ',
    'two_factor_enrolled' => '2FA Device Enrolled ',
    'two_factor_active'   => '2FA Active ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/sr-CS/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Ovaj korisnik može da se uloguje',
    'activated_disabled_help_text' => 'Ne možete da menjate status aktivacije za sopstveni nalog.',
    'assets_user'       => 'Imovina dodijeljena za :name',
    'bulk_update_warn'	=> 'Nameravate uređivati ​​svojstva korisnika :user_count users. Imajte na umu da ne možete menjati vlastite korisničke atribute pomoću ovog obrasca i morati sami uređivati ​​vlastiti nalog pojedinačno.',
    'bulk_update_help'	=> 'Ovaj vam obrazac omogućava ažuriranje više korisnika odjednom. Popunite polja koja su vam potrebna za promjenu. Sva polja koja su ostala prazna će ostati nepromenjena.',
    'current_assets'    => 'Imovina dodeljena ovom koriniku',
    'clone'             => 'Kloniraj korisnika',
    'contact_user'      => 'Kontakt :name',
    'edit'              => 'Edit User',
    'filetype_info'     => 'Dopuštene vrste datoteka su png, gif, jpg, jpeg, doc, docx, pdf, txt, zip i rar.',
    'history_user'      => 'Istorija za :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Kliknite ovdje da biste ih vratili.',
    'last_login'        => 'Poslednja prijava',
    'ldap_config_text'  => 'Postavke LDAP konfiguracije mogu se pronaći u Administrator> Postavke. Odabrana lokacija (opcionalno) će biti podešena za sve importovane korisnike.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Software Checked out to :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Prikaži korisnika :name',
    'usercsv'           => 'CSV file',
    'two_factor_admin_optin_help' => 'Your current admin settings allow selective enforcement of two-factor authentication.  ',
    'two_factor_enrolled' => '2FA Device Enrolled ',
    'two_factor_active'   => '2FA Active ',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
